@@ -1,6 +1,6 @@
 # Default selections run by the software (can be changed by the user):
 
-FILEPATH = "/Users/holly/Desktop/dotscanner-main/images/demo"
+FILEPATH = ""
 # Path to the file or directory of files that should be used. The default value is an empty string: ""
 
 PROGRAM = "density"
